"Messages used to interact with the ActorSystem Admin"


class SystemShutdown: pass   # Message sent to Admin when shutting down the entire ActorSystem
class SystemShutdownCompleted: pass


class PendingActor(object):
    """Message sent to the local Admin to request an Actor be created that
    might need to be created in a remote ActorSystem.  An Actor sends
    this message when it is unable to create the child Actor directly
    (usually because of a capabilities mismatch).  If the ActorSystem
    Admin has a Convention partner that can supply the requested Actor
    functionality then it may issue a CreateActorForRemote to that
    convention partner.

    actorClass

        The class of the new Actor to be started

    forActor

        The Actor which has requested the new Actor creation

    instanceNumForActor

        The instance number from the forActor for this new Actor
        creation.  This is unique to the requesting forActor and helps
        the forActor map the original Local ActorAddress to the final
        useable ActorAddress.

    targetActorReq

        If specified, this is a picklable requirements object supplied
        by the creating Actor that is passed to the target Actor
        class's capability check to confirm that the target Actor will
        be able to provide the capabilities requested by the creating
        Actor.  The actual type of this object is opaque to the
        ActorSystem and it is simply supplied to the target Actor; the
        requesting Actor must specify targetActorReq in a form
        understood by the target Actor.

    globalName

        If not None, specifies the global name to register this Actor
        under within this ActorSystem.  If an Actor already exists
        under this name, that Actor's address is returned instead of
        creating a new Actor (and all other actor creation parameters
        are ignored).

    """
    def __init__(self, actorClass, forActor, instanceNumForActor,
                 targetActorReq, globalName, sourceHash=None):
        self.actorClass     = actorClass
        self.forActor       = forActor
        self.instanceNum    = instanceNumForActor
        self.targetActorReq = targetActorReq
        self.globalName     = globalName
        self.sourceHash     = sourceHash


class PendingActorResponse:
    def __init__(self, forActor, instanceNumForActor, isSuccess=False, actualAddress=None):
        self.forActor      = forActor
        self.instanceNum   = instanceNumForActor
        self.isSuccess     = isSuccess
        self.actualAddress = actualAddress
