"Messages exchanged between ActorSystems that are part of a Convention"

# ----------------------------------------------------------------------
# ActorSystem interaction
#
# Multiple ActorSystems can interact in a Convention.  All
# ActorSystems that can participate in a Convention must support the
# following message exchanges between themselves.


class ConventionRegister(object):
    "Message sent between ActorSystems to join the systems together in a Convention."
    def __init__(self, adminAddress, capabilities, firstTime=False):
        '''firstTime: this is my first registration: I am a new remote system.
                      Anything you thought you knew about me might be wrong.'''
        self.adminAddress = adminAddress
        self.capabilities = capabilities
        self.firstTime = firstTime


class ConventionDeRegister(object):
    "Message sent between ActorSystems to exit a previously joined Convention."
    def __init__(self, adminAddress):
        self.adminAddress = adminAddress


class CreateActorForRemote(object):
    "Message sent between ActorSystems in a Convention to request remote Actor creation."
    # Nearly identical to PendingActor except PendingActor is
    # Actor-->ActorSystem whereas CreateActorForRemote is
    # ActorSystem-->ActorSystem.
    def __init__(self, actorClass, forActor, instanceNumForActor,
                 targetActorRequirements, globalName=None, adminAddr=None,
                 sourceHash=None):
        self.actorClass  = actorClass
        self.forActor    = forActor
        self.instanceNum = instanceNumForActor
        self.targetActorRequirements = targetActorRequirements
        self.globalName  = globalName
        self.adminAddr   = adminAddr
        self.sourceHash  = sourceHash


class RemoteActorCreated(object):
    "Message sent from ActorSystem to ActorSystem in response to CreateActorForRemote"
    def __init__(self, createActorForRemoteMsg, createdActorAddress):
        self.createActorForRemoteMsg = createActorForRemoteMsg
        self.createdActorAddress     = createdActorAddress


class RemoteActorCreateFailed(object):
    "Message sent from ActorSystem to ActorSystem in response to CreateActorForRemote"
    def __init__(self, createActorForRemoteMsg, reasonMessage):
        self.createActorForRemoteMsg = createActorForRemoteMsg
        self.reasonMessage           = reasonMessage
