"Status messages for querying Actors or ActorSystems"

# ----------------------------------------------------------------------
# ActorSystem diagnostics
#
# An ActorSystem should support the following messages which allow
# diagnostic queries and monitoring.

class Thespian_StatusReq(object):
    "Sent to an ActorSystem or an Actor to request a status response"
    pass

class Thespian_SystemStatus(object):
    "ActorSystem response to a Thespian_StatusReq"
    def __init__(self, conventionLeader=None, logger=None, childActors=None, capabilities=None):
        self.childActors         = childActors or []  # array of addresses
        self.conventionLeader    = conventionLeader
        self.capabilities        = {} if capabilities is None else capabilities
        self.loggingActor        = logger
        self.conventionRegisterTime = None
        self.conventionAttendees = []  # array of ConventionMember objects
        self.pendingMessages     = []  # array of (fromActor, toActor, msgstr) tuples
        self.deadLetterAddresses = []
        self.globalActors = {}
    def addChild(self, childAddress): self.childActors.append(childAddress)
    def addDeadLetter(self, deadAddress): self.deadLetterAddresses.append(deadAddress)
    def addConventioneer(self, conventionMember): self.conventionAttendees.append(conventionMember)
    def setConventionRegisterTime(self, time): self.conventionRegisterTime = time
    def addPendingMessage(self, fromActor, toActor, msgstr):
        self.pendingMessages.append( (fromActor, toActor, msgstr) )
    def addGlobalActor(self, name, address): self.globalActors[name] = address


# Likewise the management of each Actor should support the following diagnostics

class Thespian_ActorStatus(object):
    def __init__(self, address, actorClass, adminAddress, childActors=None, pendingWakeups=None):
        self.actorAddress    = address
        self.actorClass      = actorClass
        self.adminAddress    = adminAddress
        self.childActors     = childActors or []  # array of (addresses, pid)
        self.pendingMessages = []  # array of (toActor, msgstr) tuples
        self.pendingWakeups  = pendingWakeups or {}  # key = wakeup time, value = array of WakeupMessages
    def addChild(self, childAddress, childPid): self.childActors.append((childAddress, childPid))
    def addPendingMessage(self, toActor, msgstr): self.pendingMessages.append( (toActor, msgstr) )


