"This module provides a base class for transports to children that are asynchronously created.  It handles issues related to ActorLocalAddress resolution."

from thespian.system.addressManager import ActorLocalAddress, CannotPickleAddress


class asyncTransportBase(object):

    # Expects:
    #   self.serializer         - serializer callable that returns serialized form of intent that should be sent

    def scheduleTransmit(self, transmitIntent):
        """Requests that a transmit be performed.  The message and target
           address must be fully valid at this point; any local
           addresses should throw a CannotPickleAddress exception and
           the caller is responsible for retrying later when those
           addresses are available.

        """

        # Verify the target address is useable
        targetAddr = transmitIntent.targetAddr
        targetAddrDetails = targetAddr.addressDetails
        if isinstance(targetAddrDetails, ActorLocalAddress):
            targetAddr = targetAddrDetails.addressManager.sendingAddress(targetAddr)
            if not targetAddr:
                raise CannotPickleAddress(transmitIntent.targetAddr)
            transmitIntent.changeTargetAddr(targetAddr)

        # Verify that the message can be serialized.
        transmitIntent.serMsg = self.serializer(transmitIntent)

        # If there's nothing to send, that's implicit success
        if not transmitIntent.serMsg:
            transmitIntent.result = SendStatus.Sent
            transmitIntent.completionCallback()
            return

        self._scheduleTransmitActual(transmitIntent)
